@@ -4,7 +4,7 @@ use strict;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
 use Carp;
 use 5.005;
-our $VERSION = '1.69';
+our $VERSION = '1.70';
 
 require Exporter;
 
@@ -506,8 +506,6 @@ sub _build_ignore {
     return $ignore;
 }
 
-use utf8;
-
 my $alpha = qr/[^\W\d_]/;
 my $notalpha = qr/[\W\d_]/;
 my $word = qr/\pL(?:\pL'?)*/;
@@ -521,7 +519,6 @@ sub recase {
 
     my $text = "";
     my @pieces = split /(&[a-z]+;)/i, $origtext;
-    use Data::Dumper 'Dumper';
     push @pieces, "" if @pieces % 2;
     return $text unless @pieces;
     local $_ = shift @pieces;
@@ -675,7 +672,7 @@ sub toRoman($$)
 
 # BITS OF A NUMERIC VALUE
 
-my $num = q/(?:\d{1,3}\b(?!:\d\d\b))/;     # Ignore 8:20 etc.
+my $num = q/(?:[0-9]{1,3}\b(?!:[0-9][0-9]\b))/;     # Ignore 8:20 etc.
 my $let = q/[A-Za-z]/;
 my $pbr = q/[[(<]/;
 my $sbr = q/])>/;
@@ -877,7 +874,7 @@ Text::Autoformat - Automatic text wrapping and reformatting
 
 =head1 VERSION
 
-This document describes version 1.69 of Text::Autoformat
+This document describes version 1.70 of Text::Autoformat
 
 =head1 SYNOPSIS
 
